@@ -1,4 +1,4 @@
-from django.conf.urls.defaults import patterns, url
+from django.conf.urls.defaults import *
 
 urlpatterns = patterns('tendenci.addons.corporate_memberships.views',
     url(r'^$', 'search', name="corp_memb"),
@@ -83,6 +83,9 @@ urlpatterns = patterns('tendenci.addons.corporate_memberships.views',
     url(r'^delete_corp_rep/(?P<id>\d+)/$', 'delete_corp_rep',
         name="corp_membership.delete_rep"),
 
+    # notice
+    (r'^notices/', include('tendenci.addons.corporate_memberships.notices.urls')),
+
     # report
     url(r"^reports/summary/$", "summary_report",
         name="corp_membership.summary_report"),
