@@ -775,28 +775,32 @@ class Image(OrderingBaseModel, ImageModel, TendenciBaseModel):
     def get_next(self, set=None):
         # decide which set to pull from
         if set:
-            images = Image.objects.filter(photoset=set, id__lt=self.id)
+            images = Image.objects.filter(photoset=set, position__gt=self.position)
         else:
-            images = Image.objects.filter(id__lt=self.id)
-        images = images.values_list("id", flat=True)
-        images = images.order_by('-id')
-        try:
-            return Image.objects.get(id=max(images))
-        except ValueError:
-            return None
+            images = Image.objects.filter(position__gt=self.position)
+        images = images.values_list("position", flat=True)
+        images = images.order_by('-position')
+        if set:
+            try:
+                return Image.objects.get(photoset=set, position=min(images))
+            except (ValueError, Image.MultipleObjectsReturned):
+                return None
+        return None
 
     def get_prev(self, set=None):
         # decide which set to pull from
         if set:
-            images = Image.objects.filter(photoset=set, id__gt=self.id)
+            images = Image.objects.filter(photoset=set, position__lt=self.position)
         else:
-            images = Image.objects.filter(id__gt=self.id)
-        images = images.values_list("id", flat=True)
-        images = images.order_by('-id')
-        try:
-            return Image.objects.get(id=min(images))
-        except ValueError:
-            return None
+            images = Image.objects.filter(position__lt=self.position)
+        images = images.values_list("position", flat=True)
+        images = images.order_by('-position')
+        if set:
+            try:
+                return Image.objects.get(photoset=set, position=max(images))
+            except (ValueError, Image.MultipleObjectsReturned):
+                return None
+        return None
 
     def get_first(self, set=None):
         # decide which set to pull from
@@ -804,12 +808,23 @@ class Image(OrderingBaseModel, ImageModel, TendenciBaseModel):
             images = Image.objects.filter(photoset=set)
         else:
             return None
-        images = images.values_list("id", flat=True)
-        images = images.order_by('-id')
-        try:
-            return Image.objects.get(id=max(images))
-        except ValueError:
-            return None
+        images = images.values_list("position", flat=True)
+        images = images.order_by('-position')
+        if set:
+            try:
+                return Image.objects.get(photoset=set, position=min(images))
+            except (ValueError, Image.MultipleObjectsReturned):
+                return None
+        return None
+
+    def get_position(self, set=None):
+        # decide which set to pull from
+        if set:
+            images = Image.objects.filter(photoset=set, position__lte=self.position)
+        else:
+            images = Image.objects.filter(position__lte=self.position)
+        position = images.count()
+        return position
 
     def is_public_photo(self):
         return all([self.is_public,
