@@ -32,8 +32,6 @@ SITE_ADDONS_PATH = os.path.join(PROJECT_ROOT, 'addons')
 
 DATABASES = env('DATABASES', {'default': dj_database_url.config(default='postgres://localhost')})
 
-DATABASES['default']['OPTIONS'] = {'autocommit': True}
-
 
 # -------------------------------------- #
 # DATABASES - EXAMPLE FROM DJANGO 1.4
@@ -70,6 +68,9 @@ DATABASES = {
 }
 """
 
+if "postgresql" in DATABASES['default']['ENGINE']:
+    DATABASES['default']['OPTIONS'] = {'autocommit': True}
+
 
 # Local time zone for this installation. Choices can be found here:
 # http://en.wikipedia.org/wiki/List_of_tz_zones_by_name
@@ -167,17 +168,19 @@ AWS_ACCESS_KEY_ID = env('AWS_ACCESS_KEY_ID', '')
 AWS_SECRET_ACCESS_KEY = env('AWS_SECRET_ACCESS_KEY', '')
 AWS_STORAGE_BUCKET_NAME = env('AWS_STORAGE_BUCKET_NAME', '')
 
-USE_S3_STORAGE = all([AWS_LOCATION,
-                    AWS_ACCESS_KEY_ID,
-                    AWS_SECRET_ACCESS_KEY,
-                    AWS_STORAGE_BUCKET_NAME])
+USE_S3_STORAGE = all([
+    AWS_LOCATION,
+    AWS_ACCESS_KEY_ID,
+    AWS_SECRET_ACCESS_KEY,
+    AWS_STORAGE_BUCKET_NAME
+])
 
 if USE_S3_STORAGE:
 
     INSTALLED_APPS += (
-                       'storages',
-                       's3_folder_storage',
-                       )
+        'storages',
+        's3_folder_storage',
+    )
     # media
     DEFAULT_S3_PATH = "%s/media" % AWS_LOCATION
     DEFAULT_FILE_STORAGE = 'tendenci.libs.boto_s3.utils.DefaultStorage'
@@ -359,10 +362,12 @@ MAILGUN_SMTP_LOGIN = env('MAILGUN_SMTP_LOGIN', '')
 MAILGUN_SMTP_PASSWORD = env('MAILGUN_SMTP_PASSWORD', '')
 MAILGUN_SMTP_PORT = env('MAILGUN_SMTP_PORT', '')
 
-USE_MAILGUN = all([MAILGUN_SMTP_SERVER,
-                MAILGUN_SMTP_LOGIN,
-                MAILGUN_SMTP_PASSWORD,
-                MAILGUN_SMTP_PORT])
+USE_MAILGUN = all([
+    MAILGUN_SMTP_SERVER,
+    MAILGUN_SMTP_LOGIN,
+    MAILGUN_SMTP_PASSWORD,
+    MAILGUN_SMTP_PORT
+])
 
 if USE_MAILGUN:
     EMAIL_USE_TLS = True
